
/* 
__________________________________________________________________________________________________________
|
| Author:         Tom Mills/Microsoft
| Create date:  08/07/2008
| Description:    Compares batch execution statistics from two databases created with the ReadTrace utility.
|                       The first database is data captured from the database during the load test cycle.
|                       The second database is data captured from the database during an Ostress replay.
| Note:                 This script can be used with the SQL Server RML utilities.
|                       All deltas are calculated as second run - first run = delta value.
|_________________________________________________________________________________________________________
*/
 
DECLARE @SQLStr as NVARCHAR(2048)
DECLARE @PreRunDatabase AS VARCHAR(256)
DECLARE @PostRunDatabase AS VARCHAR(256)
 
-- Set the names for the ReadTrace databases to be compared
SET @PreRunDatabase = 'DatabaseName.readtrace.'
SET @PostRunDatabase = 'DatabaseName.readtrace.'
 
-- Build the SQL string for the query
SET @SQLStr =
      N'SELECT PreRun_Batch_Seq AS Batch_Seq,
                   PreRunUB.normtext AS SQL_Text,
                   PreRun_Duration,
                   PostRun_Duration,
                   (PostRun_Duration - PreRun_Duration) AS Duration_Delta,
                   PreRun_Reads,
                   PostRun_Reads,
                   (PostRun_Reads - PreRun_Reads) AS Reads_Delta,
                   PreRun_Writes,
                   PostRun_Writes,
                   (PostRun_Writes - PreRun_Writes) AS Writes_Delta,
                   PreRun_CPU,
                   PostRun_CPU,
                   (PostRun_CPU - PreRun_CPU) AS CPU_Delta
            FROM (SELECT row_number() OVER (ORDER BY batchseq) AS PreRun_Batch_Seq,
                  hashid AS PreRun_HashID,
                  duration AS PreRun_Duration, 
                  reads AS PreRun_Reads, 
                  writes AS PreRun_Writes, 
                  cpu AS PreRun_CPU
                  FROM ' + @PreRunDatabase + 'tblbatches) PreRun
            JOIN (SELECT row_number() OVER (ORDER BY batchseq) as PostRun_Batch_Seq,
                  hashid AS PostRun_HashID,
                  duration AS PostRun_Duration, 
                  reads AS PostRun_Reads, 
                  writes AS PostRun_Writes, 
                  cpu AS PostRun_CPU
                  FROM ' + @PostRunDatabase + 'tblbatches) PostRun
            ON PostRun.PostRun_Batch_Seq = PreRun.PreRun_Batch_Seq
            JOIN ' + @PreRunDatabase + 'tblUniqueBatches PreRunUB
            ON PreRunUB.hashid = PreRun.PreRun_HashID'
 
-- Execute the query
EXEC sp_executesql @SQLStr;
GO
 